SOUND RANSAC
================

-   [Libraries](#libraries)
-   [Functions](#functions)
-   [Sample data](#sample-data)
-   [Data from Breast Invasive Carcinoma (BRCA)](#data-from-breast-invasive-carcinoma-brca)
-   [Test run](#test-run)
    -   [Ransac with original data](#ransac-with-original-data)
    -   [Ransac with perturbation in first 10 and last 10](#ransac-with-perturbation-in-first-10-and-last-10)

Libraries
---------

``` r
library(ggplot2)
library(glmnet)
```

    ## Loading required package: Matrix

    ## Loading required package: parallel

    ## Loaded glmnet 3.0-99

``` r
library(futile.logger)
library(parallel)
library(ggbeeswarm)
source(file.path('functions', 'ransac.R'))
```

Functions
---------

    ## NULL

    ## NULL

    ## NULL

Sample data
-----------

from [UCLA](http://statistics.ats.ucla.edu/stat/r/dae/logit.htm)

``` r
# http://statistics.ats.ucla.edu/stat/r/dae/logit.htm
mydata <- read.csv("http://www.ats.ucla.edu/stat/data/binary.csv")
#
xdata <- as.matrix(mydata[,c('gpa','rank','gre')])
ydata <- mydata$admit
#
#
xdata.info <- t(sapply(as.data.frame(xdata), function(val){c(mean(val),sd(val))}))
colnames(xdata.info) <- c('Mean', 'SD')
#
flog.info('Size of dataset', dim(xdata), capture = T)
```

    ## INFO [2017-01-06 21:41:54 27996] Size of dataset
    ## 
    ## [1] 400   3

``` r
flog.info('Mean | Standard deviations', xdata.info, capture = T)
```

    ## INFO [2017-01-06 21:41:54 27996] Mean | Standard deviations
    ## 
    ##          Mean          SD
    ## gpa    3.3899   0.3805668
    ## rank   2.4850   0.9444602
    ## gre  587.7000 115.5165364

``` r
#
fit2 <- cv.glmnet(xdata, ydata, family = 'binomial')
plot(fit2)
```

![](ransac_files/figure-markdown_github/data-1.png)

Data from Breast Invasive Carcinoma (BRCA)
------------------------------------------

``` r
load('dataLogitBRCA.RData')
xdata <- dataX
ydata <- data.Y
rm(dataX, data.Y)
#
xdata.info <- t(sapply(as.data.frame(xdata), function(val){c(mean(val),sd(val))}))
colnames(xdata.info) <- c('Mean', 'SD')
#
flog.info('Size of dataset', dim(xdata), capture = T)
```

    ## INFO [2017-01-06 21:41:54 27996] Size of dataset
    ## 
    ## [1] 226  26

``` r
flog.info('Mean | Standard deviations', xdata.info, capture = T)
```

    ## INFO [2017-01-06 21:41:54 27996] Mean | Standard deviations
    ## 
    ##                         Mean         SD
    ## ENSG00000003096  0.025530005 0.16808706
    ## ENSG00000078596  0.830712633 0.80216908
    ## ENSG00000081041  0.204430102 0.46606025
    ## ENSG00000102796  0.020711234 0.05291068
    ## ENSG00000104415 -0.015463426 0.13823817
    ## ENSG00000106004  0.067516347 0.17504972
    ## ENSG00000119929  0.153799901 0.13101730
    ## ENSG00000125869  0.021632157 0.18426797
    ## ENSG00000132561  0.431968156 0.49968689
    ## ENSG00000135046  2.865599454 2.67190972
    ## ENSG00000136158  0.289560157 0.33806142
    ## ENSG00000136717  0.015960060 0.11046908
    ## ENSG00000137070 -0.004021781 0.07633464
    ## ENSG00000141504  0.459926211 0.26004756
    ## ENSG00000154736  0.120756989 0.23471739
    ## ENSG00000154856  0.178958387 0.26512677
    ## ENSG00000162849 -0.070596463 0.06249744
    ## ENSG00000164220  0.106129417 0.28983405
    ## ENSG00000167641  0.090533684 0.21339588
    ## ENSG00000175806 -0.023237744 0.04577589
    ## ENSG00000181617  1.019386165 2.63438052
    ## ENSG00000187824 -0.034119113 0.06349497
    ## ENSG00000204136  0.024732539 0.11675666
    ## ENSG00000211976  0.114683430 0.48105641
    ## ENSG00000230018 -0.003849697 0.11638349
    ## ENSG00000275385  0.073216180 0.38742644

Test run
--------

``` r
# parameters
k              <- 2000
n              <- 30
threshold      <- .4
good.fit.perct <- .5
# seed to make this reproducible
my.seed        <- 209
RNGkind("L'Ecuyer-CMRG")

# cores
mc.cores <- 14
```

### Ransac with original data

``` r
set.seed(my.seed)
#
results.ransac <- ransac(xdata, ydata, n = n, threshold = threshold, good.fit.perct = good.fit.perct, k = k,
                          error.fun       = error.fun.binomial,
                          predict.fun     = predict.fun.binomial,
                          model.error.fun = model.error.fun.binomial,
                          fit.model.fun   = fit.model.fun.binomial,
                          mc.cores = mc.cores)
```

    ## DEBUG [2017-01-06 21:41:54 27996] Starting ransac...
    ## DEBUG [2017-01-06 21:47:24 27996]   Finished running all iterations, consolidating...

``` r
print.ransac.results(results.ransac, xdata, ydata, 'Original data')
```

![](ransac_files/figure-markdown_github/test-1.png)![](ransac_files/figure-markdown_github/test-2.png)

    ## INFO [2017-01-06 21:47:25 27996] RMSE:
    ##    ransac = 0.000000
    ##    glmnet = 0.000782

### Ransac with perturbation in first 10 and last 10

``` r
set.seed(my.seed)
#
ydata.pert <- ydata
len <- length(ydata)
ydata.pert[sample(which(ydata == 1),10)] <- 0
ydata.pert[sample(which(ydata == 0),10)] <- 1
#
results.ransac.pert <- ransac(xdata, ydata.pert, n = n, threshold = threshold, good.fit.perct = good.fit.perct, k = k,
                              error.fun       = error.fun.binomial,
                              predict.fun     = predict.fun.binomial,
                              model.error.fun = model.error.fun.binomial,
                              fit.model.fun   = fit.model.fun.binomial,
                              mc.cores = mc.cores)
```

    ## DEBUG [2017-01-06 21:47:26 27996] Starting ransac...
    ## DEBUG [2017-01-06 21:53:01 27996]   Finished running all iterations, consolidating...

``` r
print.ransac.results(results.ransac.pert, xdata, ydata.pert, 'With perturbation')
```

![](ransac_files/figure-markdown_github/test_perturbation-1.png)![](ransac_files/figure-markdown_github/test_perturbation-2.png)

    ## INFO [2017-01-06 21:53:02 27996] RMSE:
    ##    ransac = 0.088490
    ##    glmnet = 0.182389
