SOUND RANSAC
================

-   [Libraries](#libraries)
-   [Functions](#functions)
-   [Sample data](#sample-data)
-   [Data from Breast Invasive Carcinoma (BRCA)](#data-from-breast-invasive-carcinoma-brca)
-   [Test run](#test-run)
    -   [Ransac with original data](#ransac-with-original-data)
    -   [Ransac with perturbation in first 10 and last 10](#ransac-with-perturbation-in-first-10-and-last-10)

Libraries
---------

``` r
library(ggplot2)
library(glmnet)
```

    ## Loading required package: Matrix

    ## Loading required package: parallel

    ## Loaded glmnet 3.0-99

``` r
library(futile.logger)
library(parallel)
library(ggbeeswarm)
source(file.path('functions', 'ransac.R'))
```

Functions
---------

    ## NULL

    ## NULL

    ## NULL

Sample data
-----------

from [UCLA](http://statistics.ats.ucla.edu/stat/r/dae/logit.htm)

``` r
# http://statistics.ats.ucla.edu/stat/r/dae/logit.htm
mydata <- read.csv("http://www.ats.ucla.edu/stat/data/binary.csv")
#
xdata <- as.matrix(mydata[,c('gpa','rank','gre')])
ydata <- mydata$admit
#
#
xdata.info <- t(sapply(as.data.frame(xdata), function(val){c(mean(val),sd(val))}))
colnames(xdata.info) <- c('Mean', 'SD')
#
flog.info('Size of dataset', dim(xdata), capture = T)
```

    ## INFO [2017-01-06 19:57:46 32212] Size of dataset
    ## 
    ## [1] 400   3

``` r
flog.info('Mean | Standard deviations', xdata.info, capture = T)
```

    ## INFO [2017-01-06 19:57:46 32212] Mean | Standard deviations
    ## 
    ##          Mean          SD
    ## gpa    3.3899   0.3805668
    ## rank   2.4850   0.9444602
    ## gre  587.7000 115.5165364

``` r
#
fit2 <- cv.glmnet(xdata, ydata, family = 'binomial')
plot(fit2)
```

![](ransac_files/figure-markdown_github/data-1.png)

Data from Breast Invasive Carcinoma (BRCA)
------------------------------------------

``` r
load('dataLogitBRCA.RData')
xdata <- dataX
ydata <- data.Y
rm(dataX, data.Y)
#
xdata.info <- t(sapply(as.data.frame(xdata), function(val){c(mean(val),sd(val))}))
colnames(xdata.info) <- c('Mean', 'SD')
#
flog.info('Size of dataset', dim(xdata), capture = T)
flog.info('Mean | Standard deviations', xdata.info, capture = T)
```

Test run
--------

``` r
# parameters
k              <- 2000
n              <- 30
threshold      <- .4
good.fit.perct <- .5
# seed to make this reproducible
my.seed        <- 209
RNGkind("L'Ecuyer-CMRG")

# cores
mc.cores <- 14
```

### Ransac with original data

``` r
set.seed(my.seed)
#
results.ransac <- ransac(xdata, ydata, n = n, threshold = threshold, good.fit.perct = good.fit.perct, k = k,
                          error.fun       = error.fun.binomial,
                          predict.fun     = predict.fun.binomial,
                          model.error.fun = model.error.fun.binomial,
                          fit.model.fun   = fit.model.fun.binomial,
                          mc.cores = mc.cores)
```

    ## DEBUG [2017-01-06 19:57:46 32212] Starting ransac...

    ## Warning in mclapply(seq(k), function(ix) {: scheduled cores 13, 7, 5
    ## encountered errors in user code, all values of the jobs will be affected

    ## DEBUG [2017-01-06 20:07:21 32212]   Finished running all iterations, consolidating...

``` r
print.ransac.results(results.ransac, xdata, ydata, 'Original data')
```

![](ransac_files/figure-markdown_github/test-1.png)![](ransac_files/figure-markdown_github/test-2.png)

    ## INFO [2017-01-06 20:07:22 32212] RMSE:
    ##    ransac = 0.286667
    ##    glmnet = 0.391546

### Ransac with perturbation in first 10 and last 10

``` r
set.seed(my.seed)
#
ydata.pert <- ydata
len <- length(ydata)
ydata.pert[1:10]         <- !ydata.pert[1:10]
ydata.pert[(len-10):len] <- !ydata.pert[(len-10):len]
#
results.ransac.pert <- ransac(xdata, ydata.pert, n = n, threshold = threshold, good.fit.perct = good.fit.perct, k = k,
                              error.fun       = error.fun.binomial,
                              predict.fun     = predict.fun.binomial,
                              model.error.fun = model.error.fun.binomial,
                              fit.model.fun   = fit.model.fun.binomial,
                              mc.cores = mc.cores)
```

    ## DEBUG [2017-01-06 20:07:23 32212] Starting ransac...

    ## Warning in mclapply(seq(k), function(ix) {: scheduled core 1, 5 encountered
    ## error in user code, all values of the job will be affected

    ## DEBUG [2017-01-06 20:16:36 32212]   Finished running all iterations, consolidating...

``` r
print.ransac.results(results.ransac.pert, xdata, ydata.pert, 'With perturbation')
```

![](ransac_files/figure-markdown_github/test_perturbation-1.png)![](ransac_files/figure-markdown_github/test_perturbation-2.png)

    ## INFO [2017-01-06 20:16:37 32212] RMSE:
    ##    ransac = 0.369349
    ##    glmnet = 0.395336
